@@ -2,15 +2,18 @@
 #######################################################################
 """Container adapters the Zope 3 based ng.content.article package
 
-$Id: containeradapter.py 51224 2008-07-01 09:00:22Z cray $
+$Id: containeradapter.py 51577 2008-08-31 12:16:31Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 51224 $"
+__version__ = "$Revision: 51577 $"
  
 from zope.interface import Interface,implements
 from zope.app.container.interfaces import  IReadContainer        
-from ng.content.article.interfaces import IContentShowable, ISContent, IDocKind, IContentContainer
+from ng.content.article.interfaces import IContentShowable, IIconShowable, IAbstractShowable
+from ng.content.article.interfaces import ISContent, IDocKind, IContentContainer
+from ng.content.article.interfaces import IContentContainer, IIconContainer, IAbstractContainer
+
 
 class BaseContainerAdapter(object) :
     def __init__(self,context,*kv,**kw) :
@@ -60,9 +63,11 @@ class BaseContainerAdapter(object) :
 
 class ShowContainerAdapter(BaseContainerAdapter) :
 
+    iface = IContentShowable
+
     def __getitem__(self,key) :
         value = super(ShowContainerAdapter,self).__getitem__(key)
-        if IContentShowable.providedBy(value) :
+        if self.iface.providedBy(value) :
             try :
                 if not IDocKind(value).ishidden :
                     return value
@@ -95,4 +100,13 @@ class ContentContainerAdapter(ShowContainerAdapter) :
             return value                    
         except TypeError :
             return value
-            
\ No newline at end of file
+
+class IconContainerAdapter(ContentContainerAdapter) :
+    implements(IIconContainer) 
+    iface = IIconShowable
+
+class AbstractContainerAdapter(ContentContainerAdapter) :
+    implements(IAbstractContainer) 
+    iface = IAbstractShowable
+
+                
\ No newline at end of file
