@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based ng.content,article.article package
 
-$Id: interfaces.py 51224 2008-07-01 09:00:22Z cray $
+$Id: interfaces.py 51577 2008-08-31 12:16:31Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 51224 $"
+__version__ = "$Revision: 51577 $"
  
 from zope.interface import Interface
 from zope.schema import Text, TextLine, Field, Bool, Datetime
@@ -40,4 +40,9 @@ class IArticle(IDocShortLogo,IDocBody,IArticleContained) :
     """ Article content-class """
     pass
 
-    
\ No newline at end of file
+class IArticleLink(Interface):
+
+    def __call__(name):
+        """Returns article registered by name"""
+
+        
\ No newline at end of file
