@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based ng.content.article package
 
-$Id: interfaces.py 51224 2008-07-01 09:00:22Z cray $
+$Id: interfaces.py 51577 2008-08-31 12:16:31Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 51224 $"
+__version__ = "$Revision: 51577 $"
  
 from zope.interface import Interface,invariant,Invalid
 from zope.schema import Text, TextLine, Field, Bool, URI, Datetime, Object
@@ -97,11 +97,15 @@ class IDocShort(IDocTitle,IDocAbstract, IDocKind) :
 class IDocShortLogo(IDocShort,IDocumentLogo) :
     """ Short list of attributes of article class """
 
-
-
 class IContentShowable(Interface) :
     """ Division showable content"""
 
+class IAbstractShowable(IContentShowable) :
+    """ Division showable content"""
+
+class IIconShowable(IContentShowable) :
+    """ Division showable content"""
+
 class ICommonContainer(Interface) :
     """ Our object can be included only into ICommonContainer """                
 
@@ -117,5 +121,13 @@ class IPageContainer(IReadContainer) :
 class IContentContainer(IReadContainer) :
     """ Container content items """
 
+# Содержимое статьи show & isdivide
+class IIconContainer(IContentContainer) :
+    """ Container icons items """
+
+# Содержимое статьи show & isdivide
+class IAbstractContainer(IContentContainer) :
+    """ Container icons items """
+
 
     
\ No newline at end of file
